@@ -14,27 +14,21 @@
 
 namespace lldb_private {
 
-class LockFilePosix : public LockFileBase
-{
+class LockFilePosix : public LockFileBase {
 public:
-    explicit LockFilePosix (int fd);
-    ~LockFilePosix () override;
+  explicit LockFilePosix(int fd);
+  ~LockFilePosix() override;
 
 protected:
-    Error
-    DoWriteLock (const uint64_t start, const uint64_t len) override;
+  Status DoWriteLock(const uint64_t start, const uint64_t len) override;
 
-    Error
-    DoTryWriteLock (const uint64_t start, const uint64_t len) override;
+  Status DoTryWriteLock(const uint64_t start, const uint64_t len) override;
 
-    Error
-    DoReadLock (const uint64_t start, const uint64_t len) override;
+  Status DoReadLock(const uint64_t start, const uint64_t len) override;
 
-    Error
-    DoTryReadLock (const uint64_t start, const uint64_t len) override;
+  Status DoTryReadLock(const uint64_t start, const uint64_t len) override;
 
-    Error
-    DoUnlock () override;
+  Status DoUnlock() override;
 };
 
 } // namespace lldb_private
